==> haskell-aeson-compat-0.3.6-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.6
id: aeson-compat-0.3.6-DrMAu7T5S7F321Gq033Ffo
key: aeson-compat-0.3.6-DrMAu7T5S7F321Gq033Ffo
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Aeson.Compat
hidden-modules: Data.Aeson.Compat.Time
abi: b174fcc2d5dc652ffc50be42db119ff2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-compat-0.3.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-compat-0.3.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/aeson-compat-0.3.6
hs-libraries: HSaeson-compat-0.3.6-DrMAu7T5S7F321Gq033Ffo
depends:
    aeson-1.0.2.1-5XK8RqnOp1ECyMyMhI5r8M
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    base-compat-0.9.1-tmPpmtbHbvIDjFWbkjGrR bytestring-0.10.8.1
    containers-0.5.7.1 exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    hashable-1.2.4.0-GnltDttmBjG9qGzcjuPOH4
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.1-HUIdYN9kpfnDYb4ETBn6RW
    unordered-containers-0.2.7.2-fKwgRekRaR5O5PqcoNK7l
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-compat-0.3.6-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.6
id: aeson-compat-0.3.6-BsHypGyMVlG1Hc713JXmeP
key: aeson-compat-0.3.6-BsHypGyMVlG1Hc713JXmeP
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Aeson.Compat
hidden-modules: Data.Aeson.Compat.Time
abi: 126cf191da950643e158cbb93b86b7b5
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-compat-0.3.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-compat-0.3.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/aeson-compat-0.3.6
hs-libraries: HSaeson-compat-0.3.6-BsHypGyMVlG1Hc713JXmeP
depends:
    aeson-1.0.2.1-FRh8NWzqPiiuj2q5G5H5S
    attoparsec-0.13.1.0-IbZnQWsljer1cy7HS9Csat base-4.9.0.0
    base-compat-0.9.1-tmPpmtbHbvIDjFWbkjGrR bytestring-0.10.8.1
    containers-0.5.7.1 exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    scientific-0.3.4.9-1EMxAMphVKV1cR2UEyLvhJ
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
